#!/bin/sh

###############################################################################
#
#   deviceTRUST ICA Installation Script, Version 23.1.400.0
#
#   Installs of uninstalls the deviceTRUST Client Extension for Citrix.
#
#	To install:
#   	./ica_install.sh INSTALL
#
#   To uninstall:
#       ./ica_install.sh UNINSTALL
#
#   Copyright 2016-2023 deviceTRUST GmbH.
#
###############################################################################

# Define root ICA installation directory
ICA_ROOT=/opt/Citrix/ICAClient

# Define module.ini file
ICA_MODULE_INI=${ICA_ROOT}/config/module.ini

# Directory that this script is located
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P )"

# Backup file extension
BACKUP_EXT="backup_$(date +%F_%H-%M-%S)"
BACKUP_UNINSTALL_FILE="/tmp/deviceTRUST_module_uninstall_${BACKUP_EXT}"
BACKUP_INSTALL_FILE="/tmp/deviceTRUST_module_install_${BACKUP_EXT}"

###############################################################################
#
# Functions
#
###############################################################################

#
# Header displays on all scenarios.
#
displayHeader() {
	echo "deviceTRUST ICA Installation Script, Version 23.1.400.0"
	echo
}

#
# Displays usage to the user
#
displayUsage() { 
	echo "Installs or uninstalls the deviceTRUST ICA Client."
	echo
	echo "Usage: $0 option"
	echo
	echo "Available options include:"
	echo
	echo "  INSTALL"
	echo
	echo "      Installs the deviceTRUST ICA Client."
	echo
	echo "  UNINSTALL"
	echo
	echo "      Uninstalls the deviceTRUST ICA Client."
	echo
}

#
# Installs the deviceTRUST ICA Client.
#
install() {
	
	if test "${ICA_MODULE_INI}"
	then
		echo "Creating Virtual Channel at ${ICA_ROOT}/dtclient.dll."
		echo
		rm -f "${ICA_ROOT}/dtclient.dll"
		ln -s "${SCRIPT_DIR}/libdtclient_ica.so" "${ICA_ROOT}/dtclient.dll"

		echo "Creating a backup of ${ICA_MODULE_INI} at ${BACKUP_UNINSTALL_FILE}."
		echo
		cp "${ICA_MODULE_INI}" "${BACKUP_INSTALL_FILE}"

		echo "Registering Virtual Channel at ${ICA_MODULE_INI}."
		echo
		if awk -v register=1 -f "${SCRIPT_DIR}/ica_module.awk" "${ICA_MODULE_INI}" > "${ICA_MODULE_INI}.tmp"; then
			mv -f "${ICA_MODULE_INI}.tmp" "${ICA_MODULE_INI}"
		fi

		echo "Changes to module.ini are:"
		echo
    	diff "${BACKUP_INSTALL_FILE}" "${ICA_MODULE_INI}"
	    echo

		echo "Done."
		echo
	else
		echo "Unable to find Citrix ICA Receiver in '${ICA_ROOT}' or module.ini at '${ICA_MODULE_INI}'." 1>&2
		echo
		exit 1
	fi
}

#
# Uninstalls the deviceTRUST ICA Client.
#
uninstall() { 

	echo "Removing Virtual Channel at ${ICA_ROOT}/dtclient.dll."
	echo
	rm -f "${ICA_ROOT}/dtclient.dll"

	echo "Creating a backup of ${ICA_MODULE_INI} at ${BACKUP_UNINSTALL_FILE}."
	echo
	cp "${ICA_MODULE_INI}" "${BACKUP_UNINSTALL_FILE}"

	echo "Unregistering Virtual Channel at ${ICA_MODULE_INI}."
	echo
	if awk -v register=0 -f "${SCRIPT_DIR}/ica_module.awk" "${ICA_MODULE_INI}" > "${ICA_MODULE_INI}.tmp"; then
		mv -f "${ICA_MODULE_INI}.tmp" "${ICA_MODULE_INI}"
	fi

	echo "Changes to module.ini are:"
	echo
    diff "${BACKUP_UNINSTALL_FILE}" "${ICA_MODULE_INI}"
    echo

	echo "Done."	
	echo
}

###############################################################################
#
# Argument processing
#
###############################################################################

displayHeader

case $1 in
	"INSTALL"|"install")
	install ;;
	"UNINSTALL"|"uninstall")
	uninstall ;;
	*)
	displayUsage ;;
esac
